// Copyright (C) 2023 Roberto Rossini <roberros@uio.no>
//
// SPDX-License-Identifier: MIT

#include "hictk/balancing/common.hpp"
#include "hictk/balancing/ice.hpp"
#include "hictk/balancing/methods.hpp"
#include "hictk/balancing/scale.hpp"
#include "hictk/balancing/sparse_matrix.hpp"
#include "hictk/balancing/vc.hpp"
#include "hictk/balancing/weights.hpp"
#include "hictk/bin.hpp"
#include "hictk/bin_table.hpp"
#include "hictk/bin_table_fixed.hpp"
#include "hictk/bin_table_variable.hpp"
#include "hictk/binary_buffer.hpp"
#include "hictk/chromosome.hpp"
#include "hictk/common.hpp"
#include "hictk/cooler.hpp"
#include "hictk/cooler/attribute.hpp"
#include "hictk/cooler/common.hpp"
#include "hictk/cooler/cooler.hpp"
#include "hictk/cooler/dataset.hpp"
#include "hictk/cooler/group.hpp"
#include "hictk/cooler/index.hpp"
#include "hictk/cooler/multires_cooler.hpp"
#include "hictk/cooler/pixel_selector.hpp"
#include "hictk/cooler/singlecell_cooler.hpp"
#include "hictk/cooler/uri.hpp"
#include "hictk/cooler/utils.hpp"
#include "hictk/cooler/validation.hpp"
#include "hictk/default_delete_libdeflate.hpp"
#include "hictk/default_delete_zstd.hpp"
#include "hictk/expected_values_aggregator.hpp"
#include "hictk/file.hpp"
#include "hictk/filestream.hpp"
#include "hictk/fmt.hpp"
#include "hictk/fmt/bin.hpp"
#include "hictk/fmt/chromosome.hpp"
#include "hictk/fmt/common.hpp"
#include "hictk/fmt/genomic_interval.hpp"
#include "hictk/fmt/pixel.hpp"
#include "hictk/generic_variant.hpp"
#include "hictk/genomic_interval.hpp"
#include "hictk/genomic_units.hpp"
#include "hictk/git.hpp"
#include "hictk/hash.hpp"
#include "hictk/hic.hpp"
#include "hictk/hic/block_reader.hpp"
#include "hictk/hic/cache.hpp"
#include "hictk/hic/common.hpp"
#include "hictk/hic/file_reader.hpp"
#include "hictk/hic/file_writer.hpp"
#include "hictk/hic/file_writer_data_structures.hpp"
#include "hictk/hic/file_zoomify.hpp"
#include "hictk/hic/footer.hpp"
#include "hictk/hic/footer_cache.hpp"
#include "hictk/hic/header.hpp"
#include "hictk/hic/index.hpp"
#include "hictk/hic/interaction_block.hpp"
#include "hictk/hic/interaction_to_block_mapper.hpp"
#include "hictk/hic/pixel_selector.hpp"
#include "hictk/hic/serialized_block_pqueue.hpp"
#include "hictk/hic/utils.hpp"
#include "hictk/hic/validation.hpp"
#include "hictk/license.hpp"
#include "hictk/multires_file.hpp"
#include "hictk/numeric_utils.hpp"
#include "hictk/numeric_variant.hpp"
#include "hictk/pixel.hpp"
#include "hictk/reference.hpp"
#include "hictk/static_binary_buffer.hpp"
#include "hictk/string.hpp"
#include "hictk/suppress_warnings.hpp"
#include "hictk/tmpdir.hpp"
#include "hictk/transformers.hpp"
#include "hictk/transformers/coarsen.hpp"
#include "hictk/transformers/common.hpp"
#include "hictk/transformers/diagonal_band.hpp"
#include "hictk/transformers/join_genomic_coords.hpp"
#include "hictk/transformers/pixel_merger.hpp"
#include "hictk/transformers/stats.hpp"
#include "hictk/transformers/to_dataframe.hpp"
#include "hictk/transformers/to_dense_matrix.hpp"
#include "hictk/transformers/to_sparse_matrix.hpp"
#include "hictk/type_pretty_printer.hpp"
#include "hictk/type_traits.hpp"
#include "hictk/variant_buff.hpp"
#include "hictk/version.hpp"

int main() { std::cout << hictk::config::version::str_long() << '\n'; }
